@@ -2,14 +2,14 @@
 **  Copyright (c) 2006-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.32 2007/10/05 18:35:30 msk Exp $
+**  $Id: dkim-config.h,v 1.37 2007/10/24 06:23:47 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.32 2007/10/05 18:35:30 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.37 2007/10/24 06:23:47 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -48,19 +48,26 @@ struct configdef dkimf_config[] =
 #endif /* POPAUTH */
 	{ "TestPublicKeys",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Quarantine",			CONFIG_TYPE_BOOLEAN,	FALSE },
+#ifdef QUERY_CACHE
+	{ "QueryCache",			CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* QUERY_CACHE */
 	{ "RemoveARAll",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "RemoveARFrom",		CONFIG_TYPE_STRING,	FALSE },
 	{ "RemoveOldSignatures",	CONFIG_TYPE_BOOLEAN,	FALSE },
+#ifdef _FFR_REPLACE_RULES
+	{ "ReplaceRules",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_REPLACE_RULES */
 #ifdef _FFR_REQUIRED_HEADERS
 	{ "RequiredHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* _FFR_REQUIRED_HEADERS */
 	{ "Selector",			CONFIG_TYPE_STRING,	FALSE },
+#ifdef _FFR_SELECTOR_HEADER
+	{ "SelectorHeader",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_SELECTOR_HEADER */
 	{ "SendReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SignatureAlgorithm",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SignatureTTL",		CONFIG_TYPE_INTEGER,	FALSE },
-#ifdef _FFR_SELECT_SIGN_HEADERS
 	{ "SignHeaders",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* _FFR_SELECT_SIGN_HEADERS */
 	{ "Socket",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_STATS
 	{ "Statistics",			CONFIG_TYPE_STRING,	FALSE },
@@ -69,6 +76,7 @@ struct configdef dkimf_config[] =
 	{ "SubDomains",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Syslog",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SyslogSuccess",		CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "UMask",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
 	{ "UseSSPDeny",			CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_VBR
