@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char ar_c_id[] = "@(#)$Id: ar.c,v 1.68 2007/04/12 23:04:33 msk Exp $";
+static char ar_c_id[] = "@(#)$Id: ar.c,v 1.71 2007/07/03 13:54:48 msk Exp $";
 #endif /* !lint */
 
 /* OS stuff */
@@ -203,6 +203,41 @@ ar_free(AR_LIB lib, void *ptr)
 		free(ptr);
 }
 
+/*
+**  AR_SMASHQUEUE -- smash everything in a list of queue handles
+**
+**  Parameters:
+**  	q -- query at the head of the list to clobber
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	Very destructive.
+*/
+
+static void
+ar_smashqueue(AR_LIB lib, AR_QUERY q)
+{
+	AR_QUERY cur;
+	AR_QUERY next;
+
+	assert(lib != NULL);
+
+	if (q == NULL)
+		return;
+
+	cur = q;
+	while (cur != NULL)
+	{
+		next = cur->q_next;
+
+		ar_free(lib, cur);
+
+		cur = next;
+	}
+}
+
 /*
 **  AR_TIMELEFT -- given a start time and a duration, see how much is left
 **
@@ -1407,12 +1442,29 @@ ar_shutdown(AR_LIB lib)
 	status = pthread_join(lib->ar_dispatcher, NULL);
 	if (status == 0)
 	{
+		void *closure;
+		void (*user_free)(void *, void *);
+
+		close(lib->ar_nsfd);
 		close(lib->ar_control[1]);
 		pthread_mutex_destroy(&lib->ar_lock);
-		free(lib->ar_nsaddrs);
-		free(lib);
 
-		/* XXX -- ar_free() everything we allocated */
+		ar_smashqueue(lib, lib->ar_pending);
+		ar_smashqueue(lib, lib->ar_queries);
+		ar_smashqueue(lib, lib->ar_recycle);
+
+		if (lib->ar_tcpbuf != NULL)
+			ar_free(lib, lib->ar_tcpbuf);
+		ar_free(lib, lib->ar_querybuf);
+		ar_free(lib, lib->ar_nsaddrs);
+
+		closure = lib->ar_closure;
+		user_free = lib->ar_free;
+
+		if (user_free != NULL)
+			user_free(closure, lib);
+		else
+			free(lib);
 	}
 
 	return status;
