@@ -3,10 +3,10 @@
 **    All rights reserved.
 */
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 
 #ifndef lint
-static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.18 2007/09/18 22:12:38 msk Exp $";
+static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.20 2007/10/24 06:32:56 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -55,16 +55,16 @@ struct dkim_cache_entry
 
 /* globals */
 static pthread_mutex_t cache_stats_lock; /* stats lock */
-static u_int c_hits;			/* cache hits */
-static u_int c_queries;			/* cache queries */
-static u_int c_expired;			/* expired cache hits */
+static u_int c_hits = 0;		/* cache hits */
+static u_int c_queries = 0;		/* cache queries */
+static u_int c_expired = 0;		/* expired cache hits */
 #if DB_VERSION_MAJOR == 1
-static pthread_mutex_t cache_lock;
+static pthread_mutex_t cache_lock;	/* cache lock */
 #else /* DB_VERSION_MAJOR == 1 */
 # ifdef PTHREAD_RWLOCK_INITIALIZER
-static pthread_rwlock_t cache_rwlock;
+static pthread_rwlock_t cache_rwlock;	/* cache lock */
 # else /* PTHREAD_RWLOCK_INITIALIZER */
-static pthread_mutex_t cache_lock;
+static pthread_mutex_t cache_lock;	/* cache lock */
 static u_int r_wait;			/* readers waiting */
 static u_int r_active;			/* readers active */
 static u_int w_wait;			/* writers waiting */
@@ -683,4 +683,4 @@ dkim_cache_stats(u_int *queries, u_int *hits, u_int *expired)
 	pthread_mutex_unlock(&cache_stats_lock);
 }
 
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
