@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.23 2007/09/17 16:41:29 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.28 2007/11/15 22:43:09 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -14,6 +14,7 @@ static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.23 2007/09/17 16:41:2
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <limits.h>
 
 /* libsm includes */
 #include <sm/string.h>
@@ -409,6 +410,10 @@ dkim_canon_selecthdrs(DKIM *dkim, u_char *hdrlist, struct dkim_header **ptrs,
 		lhdrs[c] = NULL;
 
 		len = MIN(DKIM_MAXHEADER, strlen(hdrs[c]));
+		while (len > 0 &&
+		       isascii(hdrs[c][len - 1]) &&
+		       isspace(hdrs[c][len - 1]))
+			len--;
 
 		for (hdr = dkim->dkim_hhead; hdr != NULL; hdr = hdr->hdr_next)
 		{
@@ -420,6 +425,12 @@ dkim_canon_selecthdrs(DKIM *dkim, u_char *hdrlist, struct dkim_header **ptrs,
 			{
 				hlen = colon - hdr->hdr_text;
 
+				/* ignore spaces before the colon */
+				while (hlen > 0 &&
+				       isascii(hdr->hdr_text[hlen - 1]) &&
+				       isspace(hdr->hdr_text[hlen - 1]))
+					hlen--;
+
 				if (len == hlen &&
 				    strncasecmp(hdr->hdr_text, hdrs[c],
 				                hlen) == 0)
@@ -1052,6 +1063,44 @@ dkim_canon_signature(DKIM *dkim, struct dkim_header *hdr)
 	return DKIM_STAT_OK;
 }
 
+/*
+**  DKIM_CANON_MINBODY -- return number of bytes required to satisfy
+**                        canonicalizations
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**
+**  Return value:
+**  	0 -- all canonicalizations satisfied
+**  	ULONG_MAX -- at least one canonicalization wants the whole message
+**  	other -- bytes required to satisfy all canonicalizations
+*/
+
+u_long
+dkim_canon_minbody(DKIM *dkim)
+{
+	u_long minbody = 0;
+	DKIM_CANON *cur;
+
+	assert(dkim != NULL);
+
+	for (cur = dkim->dkim_canonhead; cur != NULL; cur = cur->canon_next)
+	{
+		/* skip done hashes and those which are of the wrong type */
+		if (cur->canon_done || cur->canon_hdr)
+			continue;
+
+		/* if this one wants the whole message, short-circuit */
+		if (cur->canon_remain == (off_t) -1)
+			return ULONG_MAX;
+
+		/* compare to current minimum */
+		minbody = MIN(minbody, (u_long) cur->canon_remain);
+	}
+
+	return minbody;
+}
+
 /*
 **  DKIM_CANON_BODYCHUNK -- run a body chunk through all body
 **                          canonicalizations
@@ -1255,6 +1304,11 @@ dkim_canon_closebody(DKIM *dkim)
 		if (cur->canon_done || cur->canon_hdr)
 			continue;
 
+		/* "simple" canonicalization must include at least a CRLF */
+		if (cur->canon_canon == DKIM_CANON_SIMPLE &&
+		    cur->canon_wrote == 0)
+			dkim_canon_buffer(cur, CRLF, 2);
+
 		dkim_canon_buffer(cur, NULL, 0);
 
 		/* finalize */
