@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.27 2007/09/24 20:08:31 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.29 2007/10/29 23:14:35 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -62,10 +62,10 @@ extern void dkim_error __P((DKIM *, const char *, ...));
 DKIM_STAT
 dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 {
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 	bool cached = FALSE;
 	int ttl = 0;
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 	int status;
 	int qdcount;
 	int ancount;
@@ -104,7 +104,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	snprintf(qname, sizeof qname - 1, "%s.%s.%s", sig->sig_selector,
 	         DKIM_DNSKEYNAME, sig->sig_domain);
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 	/* see if we have this data already cached */
 	if (dkim->dkim_libhandle->dkiml_cache != NULL)
 	{
@@ -122,7 +122,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		}
 		/* XXX -- do something with errors here */
 	}
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 
 #if USE_ARLIB
 # ifdef _FFR_DNS_UPGRADE
@@ -310,7 +310,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	/* get the answer count */
 	ancount = ntohs((unsigned short) hdr.ancount);
 	if (ancount == 0)
-		return DKIM_STAT_CANTVRFY;
+		return DKIM_STAT_NOKEY;
 
 	/*
 	**  Extract the data from the first TXT answer.
@@ -338,13 +338,13 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		GETSHORT(type, cp);
 		GETSHORT(class, cp);
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 		/* get the TTL */
 		GETLONG(ttl, cp);
-#else /* _FFR_QUERY_CACHE */
+#else /* QUERY_CACHE */
 		/* skip the TTL */
 		cp += INT32SZ;
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 
 		/* skip CNAME if found; assume it was resolved */
 		if (type == T_CNAME)
@@ -409,7 +409,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		}
 	}
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 	if (!cached && buf[0] != '\0' &&
 	    dkim->dkim_libhandle->dkiml_cache != NULL)
 	{
@@ -419,7 +419,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		                           qname, buf, ttl, &err);
 		/* XXX -- do something with errors here */
 	}
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 
 	return DKIM_STAT_OK;
 }
