@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.73 2007/08/20 17:02:13 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.80 2007/11/13 22:57:22 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,10 +31,10 @@ static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.73 2007/08/20 17:02:1
 #include <openssl/err.h>
 #include <openssl/sha.h>
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 /* libdb includes */
 # include <db.h>
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 
 /* libdkim includes */
 #include "dkim.h"
@@ -71,7 +71,7 @@ struct dkim_plist
 /* struct dkim_set -- a set of parameter/value pairs */
 struct dkim_set
 {
-	bool			set_done;
+	bool			set_bad;
 	dkim_set_t		set_type;
 	u_char *		set_data;
 	void *			set_udata;
@@ -87,16 +87,16 @@ struct dkim_siginfo
 	u_int			sig_bh;
 	u_int			sig_version;
 	u_int			sig_hashtype;
-	u_int			sig_sigtype;
+	u_int			sig_keytype;
 	u_int			sig_keybits;
 	size_t			sig_siglen;
 	size_t			sig_keylen;
 	size_t			sig_b64keylen;
-	time_t			sig_timestamp;
 	dkim_query_t		sig_query;
 	dkim_alg_t		sig_signalg;
 	dkim_canon_t		sig_hdrcanonalg;
 	dkim_canon_t		sig_bodycanonalg;
+	unsigned long long	sig_timestamp;
 	u_char *		sig_domain;
 	u_char *		sig_selector;
 	u_char *		sig_sig;
@@ -176,16 +176,19 @@ struct dkim
 	int			dkim_state;
 	int			dkim_timeout;
 	int			dkim_presult;
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 	u_int			dkim_cache_queries;
 	u_int			dkim_cache_hits;
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 	u_int			dkim_version;
 	u_int			dkim_sigcount;
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
 	size_t			dkim_errlen;
 	time_t			dkim_timestamp;
+#ifdef _FFR_PARSE_TIME
+	time_t			dkim_msgdate;
+#endif /* _FFR_PARSE_TIME */
 	dkim_query_t		dkim_querymethod;
 	dkim_canon_t		dkim_hdrcanonalg;
 	dkim_canon_t		dkim_bodycanonalg;
@@ -233,8 +236,8 @@ struct dkim_lib
 	u_int			dkiml_version;
 	u_int			dkiml_callback_int;
 	time_t			dkiml_fixedtime;
-	time_t			dkiml_sigttl;
-	time_t			dkiml_clockdrift;
+	unsigned long		dkiml_sigttl;
+	unsigned long		dkiml_clockdrift;
 	dkim_query_t		dkiml_querymethod;
 	void *			(*dkiml_malloc) (void *closure, size_t nbytes);
 	void			(*dkiml_free) (void *closure, void *p);
@@ -246,9 +249,9 @@ struct dkim_lib
 #endif /* USE_ARLIB */
 	u_char **		dkiml_senderhdrs;
 	u_char **		dkiml_alwayshdrs;
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 	DB *			dkiml_cache;
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 	regex_t			dkiml_hdrre;
 	regex_t			dkiml_skiphdrre;
 	DKIM_CBSTAT		(*dkiml_key_lookup) (DKIM *dkim,
@@ -257,6 +260,7 @@ struct dkim_lib
 				                     size_t buflen);
 	DKIM_CBSTAT		(*dkiml_policy_lookup) (DKIM *dkim,
 				                        u_char *query,
+				                        bool usemx,
 				                        u_char *buf,
 				                        size_t buflen,
 				                        int *qstat);
