@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.140.2.2 2007/10/15 22:58:20 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.154 2007/11/27 21:10:51 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,7 +31,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.140.2.2 2007/10/15 22:58:20 msk E
 **  	pp == patch number
 */
 
-#define	DKIM_LIB_VERSION	0x02030200
+#define	DKIM_LIB_VERSION	0x02040000
 
 /* the basics */
 #ifndef NULL
@@ -47,6 +47,13 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.140.2.2 2007/10/15 22:58:20 msk E
 # define MAXPATHLEN		256
 #endif /* ! MAXPATHLEN */
 
+#ifndef ULONG_MAX
+# define ULONG_MAX		0xffffffffL
+#endif /* ! ULONG_MAX */
+#ifndef ULLONG_MAX
+# define ULLONG_MAX		0xffffffffffffffffLL
+#endif /* ! ULLONG_MAX */
+
 #ifndef MIN
 # define MIN(x,y)		((x) < (y) ? (x) : (y))
 #endif /* ! MIN */
@@ -110,6 +117,7 @@ typedef int DKIM_STAT;
 #define	DKIM_STAT_CBREJECT	12	/* callback requested reject */
 #define	DKIM_STAT_CBINVALID	13	/* callback gave invalid result */
 #define	DKIM_STAT_CBTRYAGAIN	14	/* callback says try again later */
+#define	DKIM_STAT_CBERROR	15	/* callback error */
 
 /*
 **  DKIM_CBSTAT -- callback status code type
@@ -120,6 +128,8 @@ typedef int DKIM_CBSTAT;
 #define	DKIM_CBSTAT_CONTINUE	0	/* continue */
 #define	DKIM_CBSTAT_REJECT	1	/* reject */
 #define	DKIM_CBSTAT_TRYAGAIN	2	/* try again later */
+#define	DKIM_CBSTAT_NOTFOUND	3	/* requested record not found */
+#define	DKIM_CBSTAT_ERROR	4	/* error requesting record */
 
 /*
 **  DKIM_SIGERROR -- signature errors
@@ -157,6 +167,7 @@ typedef int DKIM_SIGERROR;
 #define DKIM_SIGERROR_EMPTY_BH		26	/* bh= empty */
 #define DKIM_SIGERROR_CORRUPT_BH	27	/* bh= corrupt */
 #define DKIM_SIGERROR_BADSIG		28	/* signature mismatch */
+#define DKIM_SIGERROR_SUBDOMAIN		29	/* unauthorized subdomain */
 
 /*
 **  DKIM_CANON -- canonicalization method
@@ -291,10 +302,11 @@ typedef int dkim_handling_t;
 #define DKIM_PRESULT_UNKNOWN		1	/* policy is "unknown" */
 #define DKIM_PRESULT_TOPLEVEL		2	/* top-level domain */
 #define DKIM_PRESULT_PARENTOK		3	/* parent domain check OK */
-#define DKIM_PRESULT_TESTFLAG		4	/* policy marked "test" */
-#define DKIM_PRESULT_ALLVALIDSIG	5	/* policy "all", valid sig. */
-#define DKIM_PRESULT_VALIDOSIG		6	/* valid originator sig. */
-#define DKIM_PRESULT_POLICYERROR	7	/* policy check failed */
+#define DKIM_PRESULT_NOSUBDOMAIN	4	/* no subdomains allowed */
+#define DKIM_PRESULT_TESTFLAG		5	/* policy marked "test" */
+#define DKIM_PRESULT_ALLVALIDSIG	6	/* policy "all", valid sig. */
+#define DKIM_PRESULT_VALIDOSIG		7	/* valid originator sig. */
+#define DKIM_PRESULT_POLICYERROR	8	/* policy check failed */
 
 /*
 **  DKIM_MODE -- mode of a handle
@@ -364,9 +376,7 @@ typedef int dkim_opts_t;
 #define	DKIM_LIBFLAGS_TMPFILES		0x01
 #define	DKIM_LIBFLAGS_KEEPFILES		0x02
 #define	DKIM_LIBFLAGS_SIGNLEN		0x04
-#ifdef _FFR_QUERY_CACHE
-# define DKIM_LIBFLAGS_CACHE		0x08
-#endif /* _FFR_QUERY_CACHE */
+#define DKIM_LIBFLAGS_CACHE		0x08
 #define DKIM_LIBFLAGS_ZTAGS		0x10
 #define DKIM_LIBFLAGS_DELAYSIGPROC	0x20
 #define DKIM_LIBFLAGS_EOHCHECK		0x40
@@ -443,14 +453,15 @@ typedef struct dkim_canon DKIM_CANON;
 struct dkim_siginfo;
 typedef struct dkim_siginfo DKIM_SIGINFO;
 
-#define DKIM_SIGFLAG_IGNORE	0x01
-#define DKIM_SIGFLAG_PROCESSED	0x02
-#define DKIM_SIGFLAG_PASSED	0x04
-#define DKIM_SIGFLAG_TESTKEY	0x08
+#define DKIM_SIGFLAG_IGNORE		0x01
+#define DKIM_SIGFLAG_PROCESSED		0x02
+#define DKIM_SIGFLAG_PASSED		0x04
+#define DKIM_SIGFLAG_TESTKEY		0x08
+#define DKIM_SIGFLAG_NOSUBDOMAIN	0x10
 
-#define DKIM_SIGBH_UNTESTED	(-1)
-#define DKIM_SIGBH_MATCH	0
-#define DKIM_SIGBH_MISMATCH	1
+#define DKIM_SIGBH_UNTESTED		(-1)
+#define DKIM_SIGBH_MATCH		0
+#define DKIM_SIGBH_MISMATCH		1
 
 #ifdef _FFR_DIFFHEADERS
 /*
@@ -604,7 +615,6 @@ extern DKIM_STAT dkim_body __P((DKIM *dkim, u_char *buf, size_t len));
 
 extern DKIM_STAT dkim_eom __P((DKIM *dkim, bool *testkey));
 
-#ifdef _FFR_QUERY_CACHE
 /*
 **  DKIM_GETCACHESTATS -- retrieve cache statistics
 **
@@ -623,7 +633,34 @@ extern DKIM_STAT dkim_eom __P((DKIM *dkim, bool *testkey));
 
 extern void dkim_getcachestats __P((u_int *queries, u_int *hits,
                                     u_int *expired));
-#endif /* _FFR_QUERY_CACHE */
+
+/*
+**  DKIM_FLUSH_CACHE -- purge expired records from the database, reclaiming
+**                      space for use by new data
+**
+**  Parameters:
+**  	lib -- DKIM library whose cache should be flushed
+**
+**  Return value:
+**  	-1 -- caching is not in effect
+**  	>= 0 -- number of flushed records
+*/
+
+extern int dkim_flush_cache __P((DKIM_LIB *lib));
+
+/*
+**  DKIM_MINBODY -- return number of bytes still expected
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**
+**  Return value:
+**  	0 -- all canonicalizations satisfied
+**  	ULONG_MAX -- at least one canonicalization wants the whole message
+**  	other -- bytes required to satisfy all canonicalizations
+*/
+
+extern u_long dkim_minbody __P((DKIM *dkim));
 
 /*
 **  DKIM_GETSIGLIST -- retrieve the list of signatures
@@ -876,6 +913,21 @@ extern DKIM_STAT dkim_set_user_context __P((DKIM *dkim, const void *ctx));
 
 extern const void *dkim_get_user_context __P((DKIM *dkim));
 
+#ifdef _FFR_PARSE_TIME
+/*
+**  DKIM_GET_MSGDATE -- retrieve value extracted from the Date: header
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**
+**  Return value:
+**  	time_t representing the value in the Date: header of the message,
+**  	or 0 if no such header was found or the value in it was unusable
+*/
+
+extern time_t dkim_get_msgdate __P((DKIM *dkim));
+#endif /* _FFR_PARSE_TIME */
+
 /*
 **  DKIM_GETMODE -- return the mode (signing, verifying, etc.) of a handle
 **
@@ -888,6 +940,19 @@ extern const void *dkim_get_user_context __P((DKIM *dkim));
 
 extern int dkim_getmode __P((DKIM *dkim));
 
+/*
+**  DKIM_GETDOMAIN -- retrieve policy domain from a DKIM context
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**
+**  Return value:           
+**  	Pointer to the domain used for policy checking (if any) or NULL if
+**  	no domain could be determined.
+*/
+
+extern u_char *dkim_getdomain __P((DKIM *dkim));
+
 /*
 **  DKIM_SET_SIGNER -- set DKIM signature's signer
 **
@@ -948,6 +1013,7 @@ extern DKIM_STAT dkim_set_key_lookup __P((DKIM_LIB *libdkim,
 extern DKIM_STAT dkim_set_policy_lookup __P((DKIM_LIB *libdkim,
                                              DKIM_CBSTAT (*func)(DKIM *dkim,
                                                                  u_char *query,
+                                                                 bool usemx,
                                                                  u_char *buf,
                                                                  size_t buflen,
                                                                  int *qstat)));
@@ -1175,6 +1241,30 @@ extern int dkim_getpresult __P((DKIM *dkim));
 
 extern const char *dkim_getpresultstr __P((int presult));
 
+/*
+**  DKIM_GETHANDLINGSTR -- retrieve handling result string
+**
+**  Parameters:
+**  	hresult -- policy result code to translate
+**
+**  Return value:
+**  	Pointer to text that describes "hresult".
+*/
+
+extern const char *dkim_gethandlingstr __P((int hresult));
+
+/*
+**  DKIM_GETPOLICYSTR -- retrieve sender policy string
+**
+**  Parameters:
+**  	policy -- policy code to translate
+**
+**  Return value:
+**  	Pointer to text that describes "policy".
+*/
+
+extern const char *dkim_getpolicystr __P((int policy));
+
 /*
 **  DKIM_OHDRS -- extract and decode original headers
 **
@@ -1244,22 +1334,6 @@ extern int rfc2822_mailbox_split __P((char *addr, char **user, char **domain));
 
 extern unsigned long dkim_ssl_version __P((void));
 
-#ifdef _FFR_QUERY_CACHE
-/*
-**  DKIM_FLUSH_CACHE -- purge expired records from the database, reclaiming
-**                      space for use by new data
-**
-**  Parameters:
-**  	lib -- DKIM library whose cache should be flushed
-**
-**  Return value:
-**  	-1 -- caching is not in effect
-**  	>= 0 -- number of flushed records
-*/
-
-extern int dkim_flush_cache __P((DKIM_LIB *lib));
-#endif /* _FFR_QUERY_CACHE */
-
 /* default list of sender headers */
 extern const u_char *default_senderhdrs[];
 
