@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.17 2007/09/20 22:21:01 msk Exp $";
+static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.18 2007/10/31 00:24:05 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -33,9 +33,11 @@ int kl;
 **
 **  Parameters:
 **  	dkim -- DKIM handle
-**  	sig -- DKIM_SIGINFO handle
+**  	query -- string to query
+**  	usemx -- MX query?
 **  	buf -- where to write the result
 **  	buflen -- how much space is available at "buf"
+**  	qstatus -- query status (returned)
 **
 **  Return value:
 **  	0 -- operation completed
@@ -43,7 +45,7 @@ int kl;
 */
 
 int
-policy_lookup(DKIM *dkim, unsigned char *query,
+policy_lookup(DKIM *dkim, unsigned char *query, bool usemx,
               unsigned char *buf, size_t buflen, int *qstatus)
 {
 	assert(dkim != NULL);
