@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.9 2007/09/17 16:37:22 msk Exp $";
+static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.10 2007/11/27 21:11:20 msk Exp $";
 #endif /* !lint */
 
 #define	HEADER01	"Received: received data 0"
@@ -62,7 +62,7 @@ static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.9 2007/09/17 16:37:22 ms
 	"A3WL/wbaHsfOYf9Y+g1NAkAGLhx67Ah+uBNK4Xvfz0YPGINX20m+CMsxAw7FOaNv\n" \
 	"IW2oWFfZCB4APkIis79Ql45AHpavwx5XodBMzZwJUvlL\n" \
 	"-----END RSA PRIVATE KEY-----\n"
-#define	PUBLICKEY	"v=DKIM1; k=rsa; t=y; p=" \
+#define	PUBLICKEY	"v=DKIM1; k=rsa; t=y:s; p=" \
 	"MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC4GUGr+d/6SFNzVLYpphnRd0QP" \
 	"GKz2uWnV65RAxa1Pw352BqizqiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFg" \
 	"F0gu3UJbNnu3+cd8k/kiQj+q4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3D" \
