@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.13 2007/08/15 01:14:23 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.14 2007/10/27 00:44:55 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -281,3 +281,185 @@ dkim_hexchar(int c)
 		return -1;
 	}
 }
+
+/*
+**  DKIM_QP_DECODE -- decode a quoted-printable string
+**
+**  Parameters:
+**  	in -- input
+**  	out -- output
+**  	outlen -- bytes available at "out"
+**
+**  Return value:
+**  	>= 0 -- number of bytes in output
+**  	-1 -- parse error
+*/
+
+int
+dkim_qp_decode(unsigned char *in, unsigned char *out, int outlen)
+{
+	unsigned char next1;
+	unsigned char next2 = 0;
+	int xl;
+	unsigned char const *p;
+	unsigned char *q;
+	unsigned char *pos;
+	unsigned char const *start;
+	unsigned char const *stop;
+	unsigned char *end;
+	unsigned char const *hexdigits = "0123456789ABCDEF";
+
+	assert(in != NULL);
+	assert(out != NULL);
+
+	start = NULL;
+	stop = NULL;
+
+	end = out + outlen;
+
+	for (p = in, q = out; *p != '\0' && q <= end; p++)
+	{
+		switch (*p)
+		{
+		  case '=':
+			next1 = *(p + 1);
+			if (next1 != '\0')
+				next2 = *(p + 2);
+
+			/* = at EOL */
+			if (next1 == '\n' ||
+			    (next1 == '\r' && next2 == '\n'))
+			{
+				stop = p;
+				if (start != NULL)
+				{
+					unsigned char const *x;
+
+					for (x = start; x <= stop; x++)
+					{
+						if (q <= end)
+						{
+							*q = *x;
+							q++;
+						}
+					}
+				}
+				start = NULL;
+				stop = NULL;
+
+				p++;
+				if (next2 == '\n')
+					p++;
+				break;
+			}
+
+			/* = elsewhere */
+			pos = (unsigned char *) strchr(hexdigits, next1);
+			if (pos == NULL)
+				return -1;
+			xl = (pos - (unsigned char *) hexdigits) * 16;
+
+			pos = (unsigned char *) strchr(hexdigits, next2);
+			if (pos == NULL)
+				return -1;
+			xl += (pos - (unsigned char *) hexdigits);
+
+			stop = p;
+			if (start != NULL)
+			{
+				unsigned char const *x;
+
+				for (x = start; x < stop; x++)
+				{
+					if (q <= end)
+					{
+						*q = *x;
+						q++;
+					}
+				}
+			}
+			start = NULL;
+			stop = NULL;
+			*q = xl;
+			q++;
+
+			p += 2;
+
+			break;
+
+		  case ' ':
+		  case '\t':
+			if (start == NULL)
+				start = p;
+			break;
+
+		  case '\r':
+			break;
+
+		  case '\n':
+			if (stop == NULL)
+				stop = p;
+			if (start != NULL)
+			{
+				unsigned char const *x;
+
+				for (x = start; x <= stop; x++)
+				{
+					if (q <= end)
+					{
+						*q = *x;
+						q++;
+					}
+				}
+			}
+
+			if (p > in && *(p - 1) != '\r')
+			{
+				if (q <= end)
+				{
+					*q = '\n';
+					q++;
+				}
+			}
+			else
+			{
+				if (q <= end)
+				{
+					*q = '\r';
+					q++;
+				}
+				if (q <= end)
+				{
+					*q = '\n';
+					q++;
+				}
+			}
+
+			start = NULL;
+			stop = NULL;
+			break;
+
+		  default:
+			if (start == NULL)
+				start = p;
+			stop = p;
+			break;
+		}
+	}
+
+	if (start != NULL)
+	{
+		unsigned char const *x;
+
+		for (x = start; x < p; x++)
+		{
+			if (q <= end)
+			{
+				*q = *x;
+				q++;
+			}
+		}
+	}
+
+	return q - out;
+}
